
# Slot: iso abbreviation


Standard abbreviation for periodicals in the International Organization for Standardization (ISO) 4 system See https://www.issn.org/services/online-services/access-to-the-ltwa/. If the 'published in' property is set, then the iso abbreviation pertains to the broader publication context (the journal) within which the given publication node is embedded, not the publication itself.

URI: [biolink:iso_abbreviation](https://w3id.org/biolink/vocab/iso_abbreviation)


## Domain and Range

[Publication](Publication.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children

 *  [article➞iso abbreviation](article_iso_abbreviation.md)

## Used by

 * [Serial](Serial.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | WIKIDATA_PROPERTY:P1160 |

